
#line 2 "lex.yy.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

/* %not-for-header */
/* %if-c-only */
/* %if-not-reentrant */

/* %endif */
/* %endif */
/* %ok-for-header */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* %if-c++-only */
/* %endif */

/* %if-c-only */

/* %endif */

/* %if-c-only */

/* %endif */

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
/* %if-c-only */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>
/* %endif */

/* %if-tables-serialization */
/* %endif */
/* end standard C headers. */

/* %if-c-or-c++ */
/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* %endif */

/* begin standard C++ headers. */
/* %if-c++-only */
/* %endif */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* %not-for-header */
/* Returned upon end-of-file. */
#define YY_NULL 0
/* %ok-for-header */

/* %not-for-header */
/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))
/* %ok-for-header */

/* %if-reentrant */
/* %endif */

/* %if-not-reentrant */

/* %endif */

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin  )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

/* %if-not-reentrant */
extern int yyleng;
/* %endif */

/* %if-c-only */
/* %if-not-reentrant */
extern FILE *yyin, *yyout;
/* %endif */
/* %endif */

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
/* %if-c-only */
	FILE *yy_input_file;
/* %endif */

/* %if-c++-only */
/* %endif */

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* %if-c-only Standard (non-C++) definition */
/* %not-for-header */
/* %if-not-reentrant */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = NULL; /**< Stack as an array. */
/* %endif */
/* %ok-for-header */

/* %endif */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* %if-c-only Standard (non-C++) definition */

/* %if-not-reentrant */
/* %not-for-header */
/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = NULL;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;
/* %ok-for-header */

/* %endif */

void yyrestart ( FILE *input_file  );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size  );
void yy_delete_buffer ( YY_BUFFER_STATE b  );
void yy_flush_buffer ( YY_BUFFER_STATE b  );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state ( void );

static void yyensure_buffer_stack ( void );
static void yy_load_buffer_state ( void );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file  );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size  );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len  );

/* %endif */

void *yyalloc ( yy_size_t  );
void *yyrealloc ( void *, yy_size_t  );
void yyfree ( void *  );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* %% [1.0] yytext/yyin/yyout/yy_state_type/yylineno etc. def's & init go here */
/* Begin user sect3 */

#define FLEX_DEBUG
typedef flex_uint8_t YY_CHAR;

FILE *yyin = NULL, *yyout = NULL;

typedef int yy_state_type;

extern int yylineno;
int yylineno = 1;

extern char *yytext;
#ifdef yytext_ptr
#undef yytext_ptr
#endif
#define yytext_ptr yytext

/* %% [1.5] DFA */

/* %if-c-only Standard (non-C++) definition */

static yy_state_type yy_get_previous_state ( void );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  );
static int yy_get_next_buffer ( void );
static void yynoreturn yy_fatal_error ( const char* msg  );

/* %endif */

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
/* %% [2.0] code to fiddle yytext and yyleng for yymore() goes here \ */\
	yyleng = (int) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
/* %% [3.0] code to copy yytext_ptr to yytext[] goes here, if %array \ */\
	(yy_c_buf_p) = yy_cp;
/* %% [4.0] data tables for the DFA and the user's section 1 definitions go here */
#define YY_NUM_RULES 65
#define YY_END_OF_BUFFER 66
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_accept[773] =
    {   0,
        2,    2,    0,    0,   66,    2,    2,    1,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,   64,   62,   61,   64,   63,   59,
       58,   59,   59,   59,   59,   59,   59,   59,   59,   59,
       59,   59,   59,    2,    1,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,   62,    0,   60,
        0,   63,   59,   58,   59,   59,   59,   59,   59,   59,
       59,   59,   59,   59,   59,   59,   59,   59,   59,   59,

       59,   59,   59,   59,   59,   59,   59,   59,   59,    1,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,   60,   59,   59,   59,
       59,   59,   59,   59,   59,   59,   59,   59,   59,   59,
       59,   59,   59,   59,   59,   59,   59,   59,   59,   59,
       59,   59,   59,   59,   59,   59,   59,   59,   59,   59,
       59,   59,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,

        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,   59,   59,
       59,   59,   59,   10,   59,   59,   59,   59,    6,   59,
       59,   59,   59,   59,   59,   59,   59,   26,   59,   59,
       59,   59,   59,   17,   59,   59,   36,   59,   59,   20,
       59,   59,   18,   59,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,   59,   59,   59,    5,
       59,   59,   59,   59,   59,   37,   38,   59,   59,   59,

       59,    7,   59,   11,   59,   52,   59,   59,   59,   59,
       59,   59,   59,   59,   59,   59,   59,   59,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    4,   59,   59,   59,
       59,   59,   59,   59,   59,   59,   14,   35,   59,   59,
       59,   59,   59,   42,   59,   59,   59,   29,   59,   59,
       59,   46,   59,   59,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,

        2,    2,   59,   59,   59,   59,   59,   59,   59,   59,
       59,   59,   59,   59,   59,   59,   59,   59,   59,   59,
       59,   59,   59,   59,   59,   59,   59,   59,   59,   59,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,   59,
       59,   19,    8,   59,   59,   59,   59,   59,   59,    0,
       59,   59,   59,   59,   59,   59,   59,   59,   59,   48,
       59,   49,   59,   59,   59,   59,   59,   59,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,

        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,   59,   59,   59,
       59,   59,   59,   59,   59,   59,    0,    3,   59,   59,
       24,   59,   59,   59,   59,   59,   44,   59,   59,   15,
       59,   59,   59,   59,   39,   59,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,   59,   59,   59,
       59,   59,   59,   59,   59,   59,   59,   59,   59,   50,
        0,    3,    0,    3,   59,   13,   59,   59,   59,   59,

       56,   40,   16,   59,   59,   59,   59,   59,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        1,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,   59,   59,   59,   59,   59,   59,   59,   33,
       59,   59,   59,   59,    3,   59,   59,   59,   59,   59,
       59,   59,   59,   59,   59,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,   43,   59,   59,   59,
       59,   59,   59,   59,   41,   59,   59,   12,   53,   59,
       59,   59,   59,   59,   59,   59,   51,    2,    2,    2,

        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,   59,    9,   27,   34,   59,   59,   32,
       59,   59,   59,   54,   57,   59,   59,   59,   59,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,   45,
       59,   59,   59,   59,   59,   21,   23,   22,   59,    2,
        2,    2,    2,    2,    2,   28,   59,   59,   59,   59,
       47,    2,    2,    2,    2,   25,   31,   30,   59,    2,
       55,    0
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    4,    5,    1,    6,    1,    1,    1,
        1,    7,    1,    1,    7,    7,    7,    8,    8,    8,
        8,    8,    8,    8,    8,    8,    8,    7,    1,    1,
        1,    1,    1,    1,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        1,    9,    1,    1,   10,    1,   11,   12,   13,   14,

       15,   16,   17,   18,   19,    7,    7,   20,   21,   22,
       23,   24,   25,   26,   27,   28,   29,   30,   31,   32,
       33,    7,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[34] =
    {   0,
        1,    2,    3,    2,    1,    4,    5,    5,    1,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5
    } ;

static const flex_int16_t yy_base[786] =
    {   0,
        0,    0,   33,    0, 1271, 1267,   65, 1272,   66, 1266,
       75,   84,   86,  108,   63,   75,   82,   88,   94,  120,
       89,   90,   64,   95, 1272, 1266, 1272,  108,    0,    0,
     1259,  112,  118,   62,   98, 1244,  112, 1254,  125,  117,
     1245, 1236, 1243, 1258, 1272,  150,  151,  153,  155, 1257,
     1251,    0,  134,  153,  154,  141,  155,  157,  176,  158,
      160,  162,  163,  167,  193,  168,  164,  113,  183,  165,
      185,  195,  191,  194,  196,  200,  197, 1256,  209, 1253,
      223,    0,    0, 1248, 1242, 1240, 1233, 1224, 1223, 1228,
      221, 1222, 1221, 1227, 1223, 1222,  222,  193,  211, 1223,

     1229, 1213,  203, 1226, 1212, 1212, 1217, 1222, 1208,  230,
      244,  234,  236,  208,  232,  102,  243,  247,  248,  249,
      250,  253,  255,  256,  257,  259,  260,  262,  264,  265,
      261,  267,  266,  279,  170,  283,  285,  284,  269,  288,
      291,  294,  292,  295,  296,  297,  302, 1220,  298, 1211,
     1215, 1221, 1220, 1201, 1218, 1217, 1194, 1198, 1214, 1196,
     1195, 1210, 1192, 1200, 1204, 1195, 1198, 1197, 1187, 1203,
     1203, 1197, 1201, 1193, 1181, 1180, 1191, 1191, 1185, 1189,
     1177, 1184,  305,  306,  310,  309,  311,  315,  318,  312,
      313,  320, 1193,  323,  335,  327,  330,  338,  328,  322,

      336, 1192,  340,  342,  346,  349,  348, 1191,  347,  354,
     1190,  350,  357,  364,  352,  351, 1189,  369, 1169, 1168,
     1179, 1162, 1169, 1179, 1169, 1172, 1159, 1154,    0, 1168,
     1173, 1174, 1168, 1171, 1157, 1151, 1147,    0, 1151, 1149,
     1161, 1155,  363,    0, 1158, 1154,    0, 1156, 1152, 1160,
     1146, 1141,    0, 1144,  372,  373,  375, 1158,  374,  376,
      380,  381,  377, 1157, 1156,  385,  382,  386,  390, 1155,
      392,  403,  395,  407,  396,  408,  400,  412,  413,  416,
      414,  417,  418,  422,  399,  420, 1135, 1133, 1133,    0,
     1137, 1147, 1142, 1146, 1135,    0,    0, 1134, 1126, 1126,

     1131,    0, 1136, 1139, 1129, 1137, 1124, 1130, 1125, 1119,
     1123, 1119, 1121, 1119, 1116, 1120, 1108, 1106, 1126,  421,
      423,  426,  427,  433,  434,  436,  437,  440, 1125, 1124,
      443,  445,  447,  469,  452, 1123,  453,  457,  455, 1122,
      458,  459,  448,  471,  478,  472,    0, 1103, 1101, 1107,
     1099, 1115, 1101, 1095, 1107, 1093,    0,    0, 1105,  443,
     1107,  488, 1108,    0, 1097, 1088, 1095,    0, 1094, 1085,
     1089, 1101, 1099, 1081,  480,  485,  484,  488,  490,  491,
      496,  497,  510,  506,  502,  461,  512,  511,  515,  514,
      516,  518,  519,  520,  525,  526,  528,  531,  530,  534,

      540,  541, 1097, 1097, 1073, 1090,  531, 1080, 1093, 1092,
     1090, 1098, 1070, 1075, 1077, 1078, 1080, 1083, 1064, 1073,
     1063, 1075, 1070, 1073, 1059, 1071, 1075, 1068, 1062, 1072,
      535,  546, 1073,  547,  550,  551,  552,  556,  557,  559,
      585,  560,  567,  558,  562,  563,  564,  587,  588,  574,
     1072,  590, 1071,  591,  592,  593,  600,  595,  596, 1050,
     1061,    0, 1066, 1056, 1051, 1045, 1045, 1044, 1044,  608,
     1053, 1042, 1052, 1047, 1049, 1036, 1048, 1041, 1038,    0,
     1037,    0, 1044, 1032,  602, 1046, 1032, 1034,  612,  613,
      624,  607,  615,  618,  621,  622,  625,  631,  654,  630,

      633, 1046,  644,  643,  652,  617,  653, 1045,  658,  659,
     1044,  661,  662,  663,  665, 1043,  667, 1035, 1038,  674,
     1027, 1026, 1027, 1017, 1016, 1015,  672,    0, 1026, 1027,
        0, 1020, 1020, 1025, 1011, 1021,    0, 1013, 1008,    0,
     1022, 1020, 1007, 1017,    0, 1008,  669,  671,  674,  682,
      683,  676,  689,  685,  691,  695,  697,  699, 1020,  708,
      574,  710,  725,  701, 1019,  707,  714,  723,  716, 1018,
     1017, 1016,  724,  725,  729,  730,  731, 1006, 1001,  989,
     1001, 1000,  998,  998, 1001,  996,  991,  987,  986,    0,
      739, 1007,  747,    0,  991,    0,  995,  986,  989,  987,

        0,    0,    0,  983,  984,  975,  983,  990,  732,  736,
      739,  744,  745,  746,  751,  992,  752,  754,  753,  759,
      759,  775,  761,  764,  766,  772,  773,  774,  775,  778,
      781,  782,  966,  979,  978,  969,  974,  965,  967,    0,
      971,  969,  979,  978,  791,  956,  960,  967,  970,  969,
      961,  963,  962,  960,  955,  970,  784,  790,  791,  794,
      795,  797,  799,  969,  800,  802,  968,  967,  803,  805,
      807,  808,  809,  812,  816,  966,    0,  953,  944,  943,
      955,  952,  940,  952,    0,  938,  937,    0,    0,  936,
      936,  935,  946,  933,  938,  939,    0,  813,  949,  948,

      947,  818,  814,  946,  830,  832,  831,  945,  944,  833,
      821,  836,  834,  918,    0,    0,    0,  931,  920,    0,
      933,  928,  910,    0,    0,  902,  889,  897,  860,  877,
      844,  845,  840,  846,  847,  876,  874,  873,  850,    0,
      858,  867,  860,  859,  852,    0,    0,    0,  841,  865,
      852,  853,  856,  857,  863,    0,  849,  834,  794,  694,
        0,  675,  634,  270,  860,    0,    0,    0,  195,  130,
        0, 1272,  889,  894,  899,  904,  909,  914,  916,  921,
      925,  930,  935,  940,  942
    } ;

static const flex_int16_t yy_def[786] =
    {   0,
      772,    1,  772,    3,  772,  773,  773,  772,  774,  775,
      776,  776,   12,   12,   12,   12,   12,   12,   12,   12,
       12,   12,   12,   12,  772,  772,  772,  777,  778,  779,
      779,  779,  779,  779,  779,  779,  779,  779,  779,  779,
      779,  779,  779,  773,  772,  773,  774,  773,  774,  775,
       12,   12,   12,   12,   12,   12,   12,   12,   12,   12,
       12,   12,   12,   12,   12,   12,   12,   12,   12,   12,
       12,   12,   12,   12,   12,   12,   12,  772,  777,  772,
      777,  778,  779,  779,  779,  779,  779,  779,  779,  779,
      779,  779,  779,  779,  779,  779,  779,  779,  779,  779,

      779,  779,  779,  779,  779,  779,  779,  779,  779,  777,
      774,   12,   12,   12,   12,   12,   12,   12,   12,   12,
       12,   12,   12,   12,   12,   12,   12,   12,   12,   12,
       12,   12,   12,   12,   12,   12,   12,   12,   12,   12,
       12,   12,   12,   12,   12,   12,  777,  779,  779,  779,
      779,  779,  779,  779,  779,  779,  779,  779,  779,  779,
      779,  779,  779,  779,  779,  779,  779,  779,  779,  779,
      779,  779,  779,  779,  779,  779,  779,  779,  779,  779,
      779,  779,   12,   12,   12,   12,   12,   12,   12,   12,
       12,   12,   12,   12,   12,   12,   12,   12,   12,   12,

       12,   12,   12,   12,   12,   12,   12,   12,   12,   12,
       12,   12,   12,   12,   12,   12,   12,   12,  779,  779,
      779,  779,  779,  779,  779,  779,  779,  779,  779,  779,
      779,  779,  779,  779,  779,  779,  779,  779,  779,  779,
      779,  779,  779,  779,  779,  779,  779,  779,  779,  779,
      779,  779,  779,  779,   12,   12,   12,   12,   12,   12,
       12,   12,   12,   12,   12,   12,   12,   12,   12,   12,
       12,   12,   12,   12,   12,   12,   12,   12,   12,   12,
       12,   12,   12,   12,   12,   12,  779,  779,  779,  779,
      779,  779,  779,  779,  779,  779,  779,  779,  779,  779,

      779,  779,  779,  779,  779,  779,  779,  779,  779,  779,
      779,  779,  779,  779,  779,  779,  779,  779,   12,   12,
       12,   12,   12,   12,   12,   12,   12,   12,   12,   12,
       12,   12,   12,   12,   12,   12,   12,   12,   12,   12,
       12,   12,   12,   12,   12,   12,  779,  779,  779,  779,
      779,  779,  779,  779,  779,  779,  779,  779,  779,  779,
      779,  779,  779,  779,  779,  779,  779,  779,  779,  779,
      779,  779,  779,  779,   12,   12,   12,   12,   12,   12,
       12,   12,   12,   12,   12,   12,   12,   12,   12,   12,
       12,   12,   12,   12,   12,   12,   12,   12,   12,   12,

       12,   12,  779,  779,  779,  779,  779,  779,  779,  779,
      779,  779,  779,  779,  779,  779,  779,  779,  779,  779,
      779,  779,  779,  779,  779,  779,  779,  779,  779,  779,
       12,   12,   12,   12,   12,   12,   12,   12,   12,   12,
      780,   12,   12,   12,   12,   12,   12,   12,   12,   12,
       12,   12,   12,   12,   12,   12,   12,   12,   12,  779,
      779,  779,  779,  779,  779,  779,  779,  779,  779,  781,
      779,  779,  779,  779,  779,  779,  779,  779,  779,  779,
      779,  779,  779,  779,  779,  779,  779,  779,   12,   12,
       12,   12,   12,   12,   12,   12,   12,  782,  783,   12,

       12,   12,   12,   12,   12,   12,   12,   12,   12,   12,
       12,   12,   12,   12,   12,   12,   12,  779,  779,  779,
      779,  779,  779,  779,  779,  779,  784,  785,  779,  779,
      779,  779,  779,  779,  779,  779,  779,  779,  779,  779,
      779,  779,  779,  779,  779,  779,   12,   12,   12,   12,
       12,   12,   12,   12,   12,   12,   12,   12,   12,  782,
      773,  782,  783,   12,   12,   12,   12,   12,   12,   12,
       12,   12,   12,   12,   12,   12,   12,  779,  779,  779,
      779,  779,  779,  779,  779,  779,  779,  779,  779,  779,
      784,  772,  784,  785,  779,  779,  779,  779,  779,  779,

      779,  779,  779,  779,  779,  779,  779,  779,   12,   12,
       12,   12,   12,   12,   12,   12,   12,   12,   12,   12,
      784,  782,   12,   12,   12,   12,   12,   12,   12,   12,
       12,   12,  779,  779,  779,  779,  779,  779,  779,  779,
      779,  779,  779,  779,  784,  779,  779,  779,  779,  779,
      779,  779,  779,  779,  779,   12,   12,   12,   12,   12,
       12,   12,   12,   12,   12,   12,   12,   12,   12,   12,
       12,   12,   12,   12,   12,   12,  779,  779,  779,  779,
      779,  779,  779,  779,  779,  779,  779,  779,  779,  779,
      779,  779,  779,  779,  779,  779,  779,   12,   12,   12,

       12,   12,   12,   12,   12,   12,   12,   12,   12,   12,
       12,   12,   12,  779,  779,  779,  779,  779,  779,  779,
      779,  779,  779,  779,  779,  779,  779,  779,  779,   12,
       12,   12,   12,   12,   12,   12,   12,   12,   12,  779,
      779,  779,  779,  779,  779,  779,  779,  779,  779,   12,
       12,   12,   12,   12,   12,  779,  779,  779,  779,  779,
      779,   12,   12,   12,   12,  779,  779,  779,  779,   12,
      779,    0,  772,  772,  772,  772,  772,  772,  772,  772,
      772,  772,  772,  772,  772
    } ;

static const flex_int16_t yy_nxt[1306] =
    {   0,
        6,    7,    8,    9,   10,    6,   11,   12,    6,   11,
       13,   11,   11,   14,   11,   15,   16,   11,   17,   18,
       11,   19,   11,   20,   11,   11,   21,   22,   23,   11,
       24,   11,   11,   25,   26,   27,   28,   29,   25,   30,
       31,   25,   30,   32,   30,   30,   33,   30,   34,   35,
       30,   36,   37,   30,   38,   30,   39,   30,   30,   40,
       41,   42,   30,   43,   30,   30,   46,   45,   45,   48,
       51,   51,   93,   61,   49,   44,   44,   45,   44,   44,
       94,   62,   51,   44,   44,   44,   45,   44,   44,   51,
       76,   52,   44,   51,   63,   51,   51,   51,   53,   54,

       64,   51,   51,   65,   68,   55,   66,   73,   75,   51,
       67,   80,  188,   77,   56,   51,   81,   95,   57,   58,
       51,   74,   59,   96,   85,   86,   60,   51,   89,   90,
       98,   87,   91,  136,   99,  105,   92,   51,   69,   70,
       88,   51,   71,  101,  102,   72,  112,  103,   51,  106,
      104,   46,   45,   45,   48,   45,   47,  110,  111,   49,
       51,   51,   51,   49,   51,   51,  113,   51,  115,   51,
       51,   51,   51,  114,   51,   51,  134,   51,  117,  207,
      135,  125,  116,   51,  123,  126,  124,  118,  132,  127,
       51,  119,   51,  138,  133,  120,  137,  121,   51,  122,

       51,   51,   51,   51,   51,  128,  129,   51,  130,  141,
      139,  140,   80,  168,  145,   51,  144,   81,  142,  169,
      143,  771,  131,  170,  146,   79,  147,  171,  175,  176,
      186,   81,  154,   80,  164,  165,  155,  166,   81,   51,
      156,   51,  157,   51,  158,  184,   45,  111,  183,  187,
       51,  167,   49,  189,   51,   51,   51,   51,  191,  192,
       51,  185,   51,   51,   51,  195,   51,   51,   51,   51,
      198,   51,   51,   51,   51,  190,   51,   51,  201,  203,
      194,  200,  193,  196,  197,  204,   51,  202,  199,  206,
       51,   51,   51,  205,  209,   51,  211,  208,   51,   51,

      210,   51,   51,   51,   51,  147,  213,  220,  214,  216,
       81,  215,   51,   51,  218,  212,   51,   51,   51,   51,
       51,  217,   51,  221,  257,   51,  260,   51,  262,   51,
       51,  255,  256,  259,   51,   51,  267,   51,  261,  258,
      265,  263,   51,   51,  268,   51,  266,   51,  269,   51,
      271,  270,  264,   51,   51,   51,   51,   51,   51,   51,
      275,   51,  279,  277,   51,  281,  273,  272,  276,  274,
      278,   51,  280,  283,  284,  282,   51,  285,  309,   51,
       51,   51,   51,   51,   51,  310,  323,   51,   51,   51,
      325,  286,   51,   51,  324,  322,  326,   51,  319,   51,

      320,  321,   51,   51,  327,  331,   51,   51,  328,  330,
       51,  329,  332,  333,   51,   51,  334,  335,  337,   51,
       51,   51,  336,   51,   51,   51,  345,   51,   51,   51,
       51,  339,  341,   51,   51,  338,  342,  340,  344,  343,
       51,   51,  379,   51,   51,  377,  375,   51,  346,  376,
       51,  382,   51,  378,   51,   51,  380,  384,  387,   51,
       51,  393,   51,  381,   51,   51,   51,  383,   51,  413,
      399,  385,  394,  414,  396,  386,   51,  397,   51,   51,
      400,  388,  389,  443,  395,   51,  398,   51,  401,  390,
      431,   51,   51,  391,  432,   51,  392,   51,   51,  402,

      416,  417,  434,   51,   51,  438,  439,  441,  418,   51,
      435,  436,  419,   51,  437,  420,  433,   51,   51,   51,
      440,   51,   51,   51,  447,   51,   51,   51,  445,  446,
      442,  444,   51,   51,  451,   51,  449,   51,   51,  456,
      453,   51,   51,  452,  448,  455,  450,   51,   51,  457,
      459,  464,  465,   51,   51,  454,  491,   51,   51,   51,
      458,  490,  489,   51,   51,   51,   51,   51,  492,   51,
       51,   51,  502,  493,   51,  500,   45,  560,  504,  494,
      503,   51,  495,  496,  497,   44,  441,   45,  498,   44,
       44,  505,  501,   44,   51,   51,  508,   51,   51,   51,

       51,  506,   51,   51,  512,  510,  513,   51,  507,  470,
      515,  527,  509,  541,   51,  542,  517,  511,  516,   51,
       51,  514,   51,  548,   51,   51,  547,  554,   51,   51,
      543,   51,   51,   45,  561,  555,  556,   51,  549,  562,
       51,   51,  569,  550,  551,  564,  565,  552,  557,  558,
       51,   51,  559,  553,   44,   44,   45,   44,   44,   51,
       51,  567,   44,  566,  568,   51,   51,  570,   51,   51,
       51,  573,   51,  574,   51,  592,   51,  576,   51,  571,
      593,   51,   51,   51,  572,  609,  575,  577,  580,   51,
       51,  610,   51,  581,  582,  614,   51,  583,   51,  616,

      612,  613,   51,  584,   51,  611,   51,  615,   51,  617,
       45,  561,  621,  622,   51,  769,  562,  618,  562,  623,
      624,   51,  619,   51,  620,   44,   44,   45,   44,   44,
       51,   51,   51,   44,  627,  625,   51,   51,   51,   51,
      626,  632,  592,   51,  629,  628,   51,  593,  631,  591,
      645,   51,   51,   51,  657,  593,  630,  658,   51,   51,
       51,   51,  592,  665,  656,  660,   51,  593,   51,  666,
      659,   51,  663,   51,  661,  664,  662,   45,  622,   51,
       51,   51,   51,  562,  669,   51,  670,  671,   51,   51,
      668,   51,  667,  673,  645,  672,  674,   51,   51,  593,

      675,   51,   51,  698,   51,  676,   51,   51,  701,   51,
       51,  702,   51,  704,   51,   51,   51,  699,  700,   51,
       51,   51,  710,   51,  703,   51,  768,  705,   51,  706,
      707,  708,  712,  709,  713,  711,  731,   51,   51,   51,
       51,   51,  732,   51,  733,  730,  734,   51,  737,  735,
      738,   51,   51,   51,   51,  751,  752,   51,  736,   51,
       51,  739,  753,   51,   51,  750,  767,   51,  766,  754,
       51,  762,   51,  761,  760,  759,  758,  757,  765,  756,
       51,   51,  755,   51,   51,  763,  770,  749,  764,   44,
       44,   44,   44,   44,   47,   47,   47,   47,   47,   50,

       50,   50,   50,   50,   51,   51,   51,   51,   51,   79,
       79,  748,   79,   79,   82,   82,  747,   82,   82,   83,
       83,  499,  499,  499,  499,  499,  528,  746,  745,  528,
      560,  560,  560,  560,  560,  563,  563,  563,  563,  563,
      591,  591,  744,  591,  591,  594,  594,  743,  742,  741,
      740,   51,   51,   51,   51,   51,   51,  729,  728,  727,
      726,  725,  724,  723,  722,  721,  720,  719,  718,  717,
      716,  715,  714,   51,   51,   51,   51,   51,  697,  696,
      695,  694,  693,  692,  691,  690,  689,  688,  687,  686,
      685,  684,  683,  682,  681,  680,  679,  678,  677,   51,

      655,  654,  653,  652,  651,  650,  649,  648,  647,  646,
      591,  644,  643,  642,  641,  640,  639,  638,  637,  636,
      635,  634,  633,   51,   51,   51,   51,   51,  608,  607,
      606,  605,  604,  603,  602,  601,  600,  599,  598,  597,
      596,  595,  590,  589,  588,  587,  586,  585,  579,  578,
       51,   51,   51,   51,  546,  545,  544,  540,  539,  538,
      537,  536,  535,  534,  533,  532,  531,  530,  529,  526,
      525,  524,  523,  522,  521,  520,  519,  518,   51,   51,
       51,  488,  487,  486,  485,  484,  483,  482,  481,  480,
      479,  478,  477,  476,  475,  474,  473,  472,  471,  470,

      469,  468,  467,  466,  463,  462,  461,  460,  430,  429,
      428,  427,  426,  425,  424,  423,  422,  421,  415,  412,
      411,  410,  409,  408,  407,  406,  405,  404,  403,   51,
       51,   51,   51,   51,  374,  373,  372,  371,  370,  369,
      368,  367,  366,  365,  364,  363,  362,  361,  360,  359,
      358,  357,  356,  355,  354,  353,  352,  351,  350,  349,
      348,  347,   51,   51,   51,   51,  318,  317,  316,  315,
      314,  313,  312,  311,  308,  307,  306,  305,  304,  303,
      302,  301,  300,  299,  298,  297,  296,  295,  294,  293,
      292,  291,  290,  289,  288,  287,   51,   51,   51,   51,

       51,  254,  253,  252,  251,  250,  249,  248,  247,  246,
      245,  244,  243,  242,  241,  240,  239,  238,  237,  236,
      235,  234,  233,  232,  231,  230,  229,  228,  227,  226,
      225,  224,  223,  222,  219,  182,  181,  180,  179,  178,
      177,  174,  173,  172,  163,  162,  161,  160,  159,  153,
      152,  151,  150,  149,  148,   84,   79,   78,   51,   45,
       45,  109,  108,  107,  100,   97,   84,   78,   45,   45,
      772,    5,  772,  772,  772,  772,  772,  772,  772,  772,
      772,  772,  772,  772,  772,  772,  772,  772,  772,  772,
      772,  772,  772,  772,  772,  772,  772,  772,  772,  772,

      772,  772,  772,  772,  772
    } ;

static const flex_int16_t yy_chk[1306] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    7,    7,    9,    9,
       15,   23,   34,   15,    9,   11,   11,   11,   11,   11,
       34,   15,   16,   11,   12,   12,   12,   12,   12,   17,
       23,   12,   12,   13,   16,   18,   21,   22,   13,   13,

       16,   19,   24,   17,   19,   13,   18,   21,   22,  116,
       18,   28,  116,   24,   13,   14,   28,   35,   14,   14,
       68,   21,   14,   35,   32,   32,   14,   20,   33,   33,
       37,   32,   33,   68,   37,   40,   33,  770,   20,   20,
       32,   53,   20,   39,   39,   20,   53,   39,   56,   40,
       39,   46,   46,   47,   47,   48,   48,   49,   49,   47,
       54,   55,   57,   49,   58,   60,   54,   61,   56,   62,
       63,   67,   70,   55,   64,   66,   67,  135,   58,  135,
       67,   62,   57,   59,   60,   63,   61,   59,   66,   64,
       69,   59,   71,   70,   66,   59,   69,   59,   73,   59,

       65,   74,   72,   75,   77,   65,   65,   76,   65,   72,
       71,   71,   79,   98,   76,  114,   75,   79,   73,   98,
       74,  769,   65,   99,   77,   81,   81,   99,  103,  103,
      114,   81,   91,  110,   97,   97,   91,   97,  110,  115,
       91,  112,   91,  113,   91,  113,  111,  111,  112,  115,
      117,   97,  111,  117,  118,  119,  120,  121,  119,  120,
      122,  113,  123,  124,  125,  123,  126,  127,  131,  128,
      126,  129,  130,  133,  132,  118,  139,  764,  129,  131,
      122,  128,  121,  124,  125,  132,  134,  130,  127,  134,
      136,  138,  137,  133,  137,  140,  139,  136,  141,  143,

      138,  142,  144,  145,  146,  147,  141,  149,  142,  144,
      147,  143,  183,  184,  146,  140,  186,  185,  187,  190,
      191,  145,  188,  149,  185,  189,  188,  192,  190,  200,
      194,  183,  184,  187,  196,  199,  196,  197,  189,  186,
      194,  191,  195,  201,  197,  198,  195,  203,  198,  204,
      200,  199,  192,  205,  209,  207,  206,  212,  216,  215,
      205,  210,  209,  207,  213,  212,  203,  201,  206,  204,
      207,  214,  210,  214,  215,  213,  218,  216,  243,  255,
      256,  259,  257,  260,  263,  243,  260,  261,  262,  267,
      262,  218,  266,  268,  261,  259,  263,  269,  255,  271,

      256,  257,  273,  275,  266,  271,  285,  277,  267,  269,
      272,  268,  272,  273,  274,  276,  274,  275,  277,  278,
      279,  281,  276,  280,  282,  283,  285,  286,  320,  284,
      321,  279,  281,  322,  323,  278,  282,  280,  284,  283,
      324,  325,  324,  326,  327,  322,  320,  328,  286,  321,
      331,  327,  332,  323,  333,  343,  325,  331,  333,  335,
      337,  335,  339,  326,  338,  341,  342,  328,  386,  360,
      343,  332,  337,  360,  339,  332,  334,  341,  344,  346,
      344,  334,  334,  386,  338,  345,  342,  375,  345,  334,
      375,  377,  376,  334,  376,  378,  334,  379,  380,  346,

      362,  362,  378,  381,  382,  381,  382,  384,  362,  385,
      379,  379,  362,  384,  380,  362,  377,  383,  388,  387,
      383,  390,  389,  391,  390,  392,  393,  394,  388,  389,
      385,  387,  395,  396,  394,  397,  392,  399,  398,  399,
      396,  400,  431,  395,  391,  398,  393,  401,  402,  400,
      402,  407,  407,  432,  434,  397,  434,  435,  436,  437,
      401,  432,  431,  438,  439,  444,  440,  442,  435,  445,
      446,  447,  444,  436,  443,  442,  561,  561,  446,  437,
      445,  450,  438,  439,  440,  441,  441,  441,  441,  441,
      441,  447,  443,  441,  448,  449,  450,  452,  454,  455,

      456,  448,  458,  459,  456,  454,  456,  457,  449,  470,
      457,  470,  452,  485,  492,  485,  459,  455,  458,  489,
      490,  456,  493,  490,  506,  494,  489,  492,  495,  496,
      485,  491,  497,  498,  498,  493,  494,  500,  491,  498,
      501,  763,  506,  491,  491,  500,  501,  491,  495,  496,
      504,  503,  497,  491,  499,  499,  499,  499,  499,  505,
      507,  504,  499,  503,  505,  509,  510,  507,  512,  513,
      514,  512,  515,  513,  517,  527,  547,  515,  548,  509,
      527,  549,  762,  552,  510,  547,  514,  517,  520,  550,
      551,  548,  554,  520,  520,  552,  553,  520,  555,  554,

      550,  551,  556,  520,  557,  549,  558,  553,  564,  555,
      560,  560,  562,  562,  566,  760,  560,  556,  562,  564,
      566,  567,  557,  569,  558,  563,  563,  563,  563,  563,
      568,  573,  574,  563,  569,  567,  575,  576,  577,  609,
      568,  577,  591,  610,  574,  573,  611,  591,  576,  593,
      593,  612,  613,  614,  610,  593,  575,  611,  615,  617,
      619,  618,  621,  619,  609,  613,  620,  621,  623,  620,
      612,  624,  617,  625,  614,  618,  615,  622,  622,  626,
      627,  628,  629,  622,  625,  630,  626,  627,  631,  632,
      624,  657,  623,  629,  645,  628,  630,  658,  659,  645,

      631,  660,  661,  657,  662,  632,  663,  665,  660,  666,
      669,  661,  670,  663,  671,  672,  673,  658,  659,  674,
      698,  703,  672,  675,  662,  702,  759,  665,  711,  666,
      669,  670,  674,  671,  675,  673,  702,  705,  707,  706,
      710,  713,  703,  712,  705,  698,  706,  733,  711,  707,
      712,  731,  732,  734,  735,  732,  733,  739,  710,  751,
      752,  713,  734,  753,  754,  731,  758,  765,  757,  735,
      755,  751,  750,  749,  745,  744,  743,  742,  754,  741,
      738,  737,  739,  736,  730,  752,  765,  729,  753,  773,
      773,  773,  773,  773,  774,  774,  774,  774,  774,  775,

      775,  775,  775,  775,  776,  776,  776,  776,  776,  777,
      777,  728,  777,  777,  778,  778,  727,  778,  778,  779,
      779,  780,  780,  780,  780,  780,  781,  726,  723,  781,
      782,  782,  782,  782,  782,  783,  783,  783,  783,  783,
      784,  784,  722,  784,  784,  785,  785,  721,  719,  718,
      714,  709,  708,  704,  701,  700,  699,  696,  695,  694,
      693,  692,  691,  690,  687,  686,  684,  683,  682,  681,
      680,  679,  678,  676,  668,  667,  664,  656,  655,  654,
      653,  652,  651,  650,  649,  648,  647,  646,  644,  643,
      642,  641,  639,  638,  637,  636,  635,  634,  633,  616,

      608,  607,  606,  605,  604,  600,  599,  598,  597,  595,
      592,  589,  588,  587,  586,  585,  584,  583,  582,  581,
      580,  579,  578,  572,  571,  570,  565,  559,  546,  544,
      543,  542,  541,  539,  538,  536,  535,  534,  533,  532,
      530,  529,  526,  525,  524,  523,  522,  521,  519,  518,
      516,  511,  508,  502,  488,  487,  486,  484,  483,  481,
      479,  478,  477,  476,  475,  474,  473,  472,  471,  469,
      468,  467,  466,  465,  464,  463,  461,  460,  453,  451,
      433,  430,  429,  428,  427,  426,  425,  424,  423,  422,
      421,  420,  419,  418,  417,  416,  415,  414,  413,  412,

      411,  410,  409,  408,  406,  405,  404,  403,  374,  373,
      372,  371,  370,  369,  367,  366,  365,  363,  361,  359,
      356,  355,  354,  353,  352,  351,  350,  349,  348,  340,
      336,  330,  329,  319,  318,  317,  316,  315,  314,  313,
      312,  311,  310,  309,  308,  307,  306,  305,  304,  303,
      301,  300,  299,  298,  295,  294,  293,  292,  291,  289,
      288,  287,  270,  265,  264,  258,  254,  252,  251,  250,
      249,  248,  246,  245,  242,  241,  240,  239,  237,  236,
      235,  234,  233,  232,  231,  230,  228,  227,  226,  225,
      224,  223,  222,  221,  220,  219,  217,  211,  208,  202,

      193,  182,  181,  180,  179,  178,  177,  176,  175,  174,
      173,  172,  171,  170,  169,  168,  167,  166,  165,  164,
      163,  162,  161,  160,  159,  158,  157,  156,  155,  154,
      153,  152,  151,  150,  148,  109,  108,  107,  106,  105,
      104,  102,  101,  100,   96,   95,   94,   93,   92,   90,
       89,   88,   87,   86,   85,   84,   80,   78,   51,   50,
       44,   43,   42,   41,   38,   36,   31,   26,   10,    6,
        5,  772,  772,  772,  772,  772,  772,  772,  772,  772,
      772,  772,  772,  772,  772,  772,  772,  772,  772,  772,
      772,  772,  772,  772,  772,  772,  772,  772,  772,  772,

      772,  772,  772,  772,  772
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 1;

static const flex_int16_t yy_rule_linenum[65] =
    {   0,
       83,   84,   86,   87,   88,   89,   90,   91,   92,   93,
       94,   95,   96,   97,   98,   99,  100,  101,  102,  104,
      105,  106,  107,  109,  110,  111,  112,  113,  114,  115,
      116,  118,  119,  120,  122,  123,  124,  125,  126,  127,
      128,  129,  130,  131,  132,  133,  134,  135,  136,  137,
      138,  140,  141,  142,  143,  144,  145,  147,  150,  153,
      160,  161,  162,  163
    } ;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "servscan.l"
/* servscan.l -- Scanner for dictd server configuration file
 * Created: Fri Feb 28 08:23:03 1997 by faith@cs.unc.edu
 * Copyright 1997, 1999, 2000, 2002 Rickard E. Faith (faith@acm.org)
 * Copyright 2002-2008 Aleksey Cheusov (vle@gmx.net)
 * 
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 1, or (at your option) any
 * later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 675 Mass Ave, Cambridge, MA 02139, USA.
 */
#line 23 "servscan.l"
#include "dictd.h"
#include "servparse.h"
extern int  yylex( void );
extern int  yydebug;
extern void yyerror( const char *message );
static void include_file( void );
static void include_complete( void );
YY_BUFFER_STATE orig_buffer = NULL;
src_Type orig_source = NULL;
#define RETURN(val) do {                  \
   yylval.token.src = src_get( yyleng );  \
   return val;                            \
} while (0)

/*
  \n    --> new line character
  \\    --> backslash
  \<NL> --> no symbol
  \"    --> double quote symbol
*/
static int escape_string (char *s, int len)
{
   int ret = 0;
   int i   = 0;

   for (i=0; i < len; ++i){
      if (s [i] != '\\'){
	 s [ret++] = s [i];
      }else if (s [i+1] == '\\'){
	 s [ret++] = '\\';

	 ++i;
      }else if (s [i+1] == 'n'){
	 s [ret++] = '\n';

	 ++i;
      }else if (s [i+1] == '"'){
	 s [ret++] = '"';

	 ++i;
      }else if (s [i+1] != '\n'){
	 s [ret++] = s [++i];
      }else{
	 ++i;
      }
   }

   return ret;
}

#line 1143 "lex.yy.c"

#line 1145 "lex.yy.c"

#define INITIAL 0
#define OTHER 1

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
/* %if-c-only */
#include <unistd.h>
/* %endif */
/* %if-c++-only */
/* %endif */
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

/* %if-c-only Reentrant structure and macros (non-C++). */
/* %if-reentrant */
/* %if-c-only */

static int yy_init_globals ( void );

/* %endif */
/* %if-reentrant */
/* %endif */
/* %endif End reentrant structures and macros. */

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( void );

int yyget_debug ( void );

void yyset_debug ( int debug_flag  );

YY_EXTRA_TYPE yyget_extra ( void );

void yyset_extra ( YY_EXTRA_TYPE user_defined  );

FILE *yyget_in ( void );

void yyset_in  ( FILE * _in_str  );

FILE *yyget_out ( void );

void yyset_out  ( FILE * _out_str  );

			int yyget_leng ( void );

char *yyget_text ( void );

int yyget_lineno ( void );

void yyset_lineno ( int _line_number  );

/* %if-bison-bridge */
/* %endif */

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( void );
#else
extern int yywrap ( void );
#endif
#endif

/* %not-for-header */
#ifndef YY_NO_UNPUT
    
    static void yyunput ( int c, char *buf_ptr  );
    
#endif
/* %ok-for-header */

/* %endif */

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * );
#endif

#ifndef YY_NO_INPUT
/* %if-c-only Standard (non-C++) definition */
/* %not-for-header */
#ifdef __cplusplus
static int yyinput ( void );
#else
static int input ( void );
#endif
/* %ok-for-header */

/* %endif */
#endif

/* %if-c-only */

        static int yy_start_stack_ptr = 0;
        static int yy_start_stack_depth = 0;
        static int *yy_start_stack = NULL;
    
    static void yy_push_state ( int _new_state );
    
    static void yy_pop_state ( void );
    
    static int yy_top_state ( void );
    
/* %endif */

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* %if-c-only Standard (non-C++) definition */
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
/* %endif */
/* %if-c++-only C++ definition */
/* %endif */
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
/* %% [5.0] fread()/read() definition of YY_INPUT goes here unless we're doing C++ \ */\
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\
/* %if-c++-only C++ definition \ */\
/* %endif */

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
/* %if-c-only */
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
/* %endif */
/* %if-c++-only */
/* %endif */
#endif

/* %if-tables-serialization structures and prototypes */
/* %not-for-header */
/* %ok-for-header */

/* %not-for-header */
/* %tables-yydmap generated elements */
/* %endif */
/* end tables serialization structures and prototypes */

/* %ok-for-header */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1
/* %if-c-only Standard (non-C++) definition */

extern int yylex (void);

#define YY_DECL int yylex (void)
/* %endif */
/* %if-c++-only C++ definition */
/* %endif */
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

/* %% [6.0] YY_RULE_SETUP definition goes here */
#define YY_RULE_SETUP \
	YY_USER_ACTION

/* %not-for-header */
/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
/* %if-c-only */
			yyin = stdin;
/* %endif */
/* %if-c++-only */
/* %endif */

		if ( ! yyout )
/* %if-c-only */
			yyout = stdout;
/* %endif */
/* %if-c++-only */
/* %endif */

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE );
		}

		yy_load_buffer_state(  );
		}

	{
/* %% [7.0] user's declarations go here */
#line 81 "servscan.l"

#line 1438 "lex.yy.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
/* %% [8.0] yymore()-related code goes here */
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

/* %% [9.0] code to set up and find next match goes here */
		yy_current_state = (yy_start);
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 773 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 1272 );

yy_find_action:
/* %% [10.0] code to find the action number goes here */
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

/* %% [11.0] code for yylineno update goes here */

do_action:	/* This label is used only to access EOF actions. */

/* %% [12.0] debug code goes here */
		if ( yy_flex_debug )
			{
			if ( yy_act == 0 )
				fprintf( stderr, "--scanner backing up\n" );
			else if ( yy_act < 65 )
				fprintf( stderr, "--accepting rule at line %ld (\"%s\")\n",
				         (long)yy_rule_linenum[yy_act], yytext );
			else if ( yy_act == 65 )
				fprintf( stderr, "--accepting default rule (\"%s\")\n",
				         yytext );
			else if ( yy_act == 66 )
				fprintf( stderr, "--(end of buffer or a NUL)\n" );
			else
				fprintf( stderr, "--EOF (start condition %d)\n", YY_START );
			}

		switch ( yy_act )
	{ /* beginning of action switch */
/* %% [13.0] actions go here */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 83 "servscan.l"
src_line(yytext,yyleng); yyless(0); BEGIN(OTHER);
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 84 "servscan.l"
src_line(yytext,yyleng); yyless(0); BEGIN(OTHER);
	YY_BREAK

case 3:
/* rule 3 can match eol */
YY_RULE_SETUP
#line 86 "servscan.l"
include_file();
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 87 "servscan.l"
RETURN(TOKEN_ACCESS);
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 88 "servscan.l"
RETURN(TOKEN_ALLOW);
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 89 "servscan.l"
RETURN(TOKEN_DENY);
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 90 "servscan.l"
RETURN(TOKEN_GROUP);
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 91 "servscan.l"
RETURN(TOKEN_DATABASE);
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 92 "servscan.l"
RETURN(TOKEN_DATABASE_EXIT);
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 93 "servscan.l"
RETURN(TOKEN_DATA);
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 94 "servscan.l"
RETURN(TOKEN_INDEX);
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 95 "servscan.l"
RETURN(TOKEN_INDEX_SUFFIX);
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 96 "servscan.l"
RETURN(TOKEN_INDEX_WORD);
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 97 "servscan.l"
RETURN(TOKEN_FILTER);
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 98 "servscan.l"
RETURN(TOKEN_PREFILTER);
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 99 "servscan.l"
RETURN(TOKEN_POSTFILTER);
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 100 "servscan.l"
RETURN(TOKEN_NAME);
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 101 "servscan.l"
RETURN(TOKEN_USER);
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 102 "servscan.l"
RETURN(TOKEN_AUTHONLY);
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 104 "servscan.l"
RETURN(TOKEN_SITE);
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 105 "servscan.l"
RETURN(TOKEN_SITE_NO_BANNER);
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 106 "servscan.l"
RETURN(TOKEN_SITE_NO_UPTIME);
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 107 "servscan.l"
RETURN(TOKEN_SITE_NO_DBLIST);
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 109 "servscan.l"
RETURN(TOKEN_INVISIBLE);
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 110 "servscan.l"
RETURN(TOKEN_DATABASE_VIRTUAL);
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 111 "servscan.l"
RETURN(TOKEN_INFO);
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 112 "servscan.l"
RETURN(TOKEN_DATABASE_LIST);
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 113 "servscan.l"
RETURN(TOKEN_DATABASE_PLUGIN);
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 114 "servscan.l"
RETURN(TOKEN_PLUGIN);
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 115 "servscan.l"
RETURN(TOKEN_DISABLE_STRAT);
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 116 "servscan.l"
RETURN(TOKEN_DEFAULT_STRAT);
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 118 "servscan.l"
RETURN(TOKEN_NOMIME_DBNAME);
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 119 "servscan.l"
RETURN(TOKEN_MIME_DBNAME);
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 120 "servscan.l"
RETURN(TOKEN_DATABASE_MIME);
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 122 "servscan.l"
RETURN(TOKEN_GLOBAL);
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 123 "servscan.l"
RETURN(TOKEN_PORT);
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 124 "servscan.l"
RETURN(TOKEN_DELAY);
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 125 "servscan.l"
RETURN(TOKEN_DEPTH);
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 126 "servscan.l"
RETURN(TOKEN_TIMESTAMP);
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 127 "servscan.l"
RETURN(TOKEN_LOG_OPTION);
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 128 "servscan.l"
RETURN(TOKEN_DEBUG_OPTION);
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 129 "servscan.l"
RETURN(TOKEN_LOCALE);
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 130 "servscan.l"
RETURN(TOKEN_ADD_STRAT);
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 131 "servscan.l"
RETURN(TOKEN_LISTEN_TO);
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 132 "servscan.l"
RETURN(TOKEN_ADDRESS_FAMILY);
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 133 "servscan.l"
RETURN(TOKEN_SYSLOG);
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 134 "servscan.l"
RETURN(TOKEN_SYSLOG_FACILITY);
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 135 "servscan.l"
RETURN(TOKEN_LOG_FILE);
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 136 "servscan.l"
RETURN(TOKEN_PID_FILE);
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 137 "servscan.l"
RETURN(TOKEN_FAST_START);
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 138 "servscan.l"
RETURN(TOKEN_WITHOUT_MMAP);
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 140 "servscan.l"
RETURN(TOKEN_LIMIT_CHILDS);
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 141 "servscan.l"
RETURN(TOKEN_LIMIT_CHILDS);
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 142 "servscan.l"
RETURN(TOKEN_LIMIT_MATCHES);
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 143 "servscan.l"
RETURN(TOKEN_LIMIT_DEFS);
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 144 "servscan.l"
RETURN(TOKEN_LIMIT_TIME);
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 145 "servscan.l"
RETURN(TOKEN_LIMIT_QUERIES);
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 147 "servscan.l"
{ yylval.token.integer = atoi(yytext);
                              RETURN(TOKEN_NUMBER);
                            }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 150 "servscan.l"
{ yylval.token.string = str_findn(yytext, yyleng);
                              RETURN(TOKEN_STRING);
                            }
	YY_BREAK
case 60:
/* rule 60 can match eol */
YY_RULE_SETUP
#line 153 "servscan.l"
{
				yylval.token.string =
				   str_findn (
				      yytext+1,
				      escape_string (yytext+1, yyleng-2));
				RETURN(TOKEN_STRING);
                            }
	YY_BREAK
case 61:
/* rule 61 can match eol */
YY_RULE_SETUP
#line 160 "servscan.l"
BEGIN(INITIAL);
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 161 "servscan.l"
src_advance( yyleng );
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 162 "servscan.l"
src_advance( yyleng );
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 163 "servscan.l"
RETURN(yytext[0]);
	YY_BREAK
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(OTHER):
#line 164 "servscan.l"
{ if (orig_buffer) include_complete();
                              else RETURN(0);
                            }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 167 "servscan.l"
ECHO;
	YY_BREAK
#line 1865 "lex.yy.c"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
/* %if-c-only */
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
/* %endif */
/* %if-c++-only */
/* %endif */
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
/* %% [14.0] code to do back-up for compressed tables and set up yy_cp goes here */
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap(  ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */
/* %ok-for-header */

/* %if-c++-only */
/* %not-for-header */
/* %ok-for-header */

/* %endif */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
/* %if-c-only */
static int yy_get_next_buffer (void)
/* %endif */
/* %if-c++-only */
/* %endif */
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr) - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2)  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if (((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

/* %if-c-only */
/* %not-for-header */
    static yy_state_type yy_get_previous_state (void)
/* %endif */
/* %if-c++-only */
/* %endif */
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
/* %% [15.0] code to get the start state into yy_current_state goes here */
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
/* %% [16.0] code to find the next state goes here */
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 773 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
/* %if-c-only */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
/* %endif */
/* %if-c++-only */
/* %endif */
{
	int yy_is_jam;
    /* %% [17.0] code to find the next state, and perhaps do backing up, goes here */
	char *yy_cp = (yy_c_buf_p);

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 773 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 772);

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT
/* %if-c-only */

    static void yyunput (int c, char * yy_bp )
/* %endif */
/* %if-c++-only */
/* %endif */
{
	char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		int number_to_move = (yy_n_chars) + 2;
		char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = (int) YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

/* %% [18.0] update yylineno here */

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}
/* %if-c-only */

/* %endif */
#endif

/* %if-c-only */
#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

/* %endif */
/* %if-c++-only */
/* %endif */
{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (int) ((yy_c_buf_p) - (yytext_ptr));
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(  ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

/* %% [19.0] update BOL and yylineno */

	return c;
}
/* %if-c-only */
#endif	/* ifndef YY_NO_INPUT */
/* %endif */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
/* %if-c-only */
    void yyrestart  (FILE * input_file )
/* %endif */
/* %if-c++-only */
/* %endif */
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE );
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file );
	yy_load_buffer_state(  );
}

/* %if-c++-only */
/* %endif */

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
/* %if-c-only */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
/* %endif */
/* %if-c++-only */
/* %endif */
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(  );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

/* %if-c-only */
static void yy_load_buffer_state  (void)
/* %endif */
/* %if-c++-only */
/* %endif */
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
/* %if-c-only */
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
/* %endif */
/* %if-c++-only */
/* %endif */
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
/* %if-c-only */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
/* %endif */
/* %if-c++-only */
/* %endif */
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2)  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file );

	return b;
}

/* %if-c++-only */
/* %endif */

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
/* %if-c-only */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
/* %endif */
/* %if-c++-only */
/* %endif */
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf  );

	yyfree( (void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
/* %if-c-only */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )
/* %endif */
/* %if-c++-only */
/* %endif */

{
	int oerrno = errno;
    
	yy_flush_buffer( b );

/* %if-c-only */
	b->yy_input_file = file;
/* %endif */
/* %if-c++-only */
/* %endif */
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

/* %if-c-only */

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
/* %endif */
/* %if-c++-only */
/* %endif */
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
/* %if-c-only */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
/* %endif */
/* %if-c++-only */
/* %endif */
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(  );
}

/* %if-c-or-c++ */
/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
/* %if-c-only */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
/* %endif */
/* %if-c++-only */
/* %endif */
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(  );
	(yy_did_buffer_switch_on_eof) = 1;
}
/* %endif */

/* %if-c-or-c++ */
/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
/* %if-c-only */
void yypop_buffer_state (void)
/* %endif */
/* %if-c++-only */
/* %endif */
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(  );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}
/* %endif */

/* %if-c-or-c++ */
/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
/* %if-c-only */
static void yyensure_buffer_stack (void)
/* %endif */
/* %if-c++-only */
/* %endif */
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}
/* %endif */

/* %if-c-only */
/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b  );

	return b;
}
/* %endif */

/* %if-c-only */
/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr )
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) );
}
/* %endif */

/* %if-c-only */
/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}
/* %endif */

/* %if-c-only */
    static void yy_push_state (int  _new_state )
/* %endif */
/* %if-c++-only */
/* %endif */
{
    	if ( (yy_start_stack_ptr) >= (yy_start_stack_depth) )
		{
		yy_size_t new_size;

		(yy_start_stack_depth) += YY_START_STACK_INCR;
		new_size = (yy_size_t) (yy_start_stack_depth) * sizeof( int );

		if ( ! (yy_start_stack) )
			(yy_start_stack) = (int *) yyalloc( new_size  );

		else
			(yy_start_stack) = (int *) yyrealloc(
					(void *) (yy_start_stack), new_size  );

		if ( ! (yy_start_stack) )
			YY_FATAL_ERROR( "out of memory expanding start-condition stack" );
		}

	(yy_start_stack)[(yy_start_stack_ptr)++] = YY_START;

	BEGIN(_new_state);
}

/* %if-c-only */
    static void yy_pop_state  (void)
/* %endif */
/* %if-c++-only */
/* %endif */
{
    	if ( --(yy_start_stack_ptr) < 0 )
		YY_FATAL_ERROR( "start-condition stack underflow" );

	BEGIN((yy_start_stack)[(yy_start_stack_ptr)]);
}

/* %if-c-only */
    static int yy_top_state  (void)
/* %endif */
/* %if-c++-only */
/* %endif */
{
    	return (yy_start_stack)[(yy_start_stack_ptr) - 1];
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

/* %if-c-only */
static void yynoreturn yy_fatal_error (const char* msg )
{
			fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}
/* %endif */
/* %if-c++-only */
/* %endif */

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/* %if-c-only */
/* %if-reentrant */
/* %endif */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
    
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/* %if-reentrant */
/* %endif */

/** Set the current line number.
 * @param _line_number line number
 * 
 */
void yyset_lineno (int  _line_number )
{
    
    yylineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str )
{
        yyin = _in_str ;
}

void yyset_out (FILE *  _out_str )
{
        yyout = _out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  _bdebug )
{
        yy_flex_debug = _bdebug ;
}

/* %endif */

/* %if-reentrant */
/* %if-bison-bridge */
/* %endif */
/* %endif if-c-only */

/* %if-c-only */
static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = NULL;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = NULL;
    (yy_init) = 0;
    (yy_start) = 0;

    (yy_start_stack_ptr) = 0;
    (yy_start_stack_depth) = 0;
    (yy_start_stack) =  NULL;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}
/* %endif */

/* %if-c-only SNIP! this currently causes conflicts with the c++ scanner */
/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Destroy the start condition stack. */
        yyfree( (yy_start_stack)  );
        (yy_start_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

/* %if-reentrant */
/* %endif */
    return 0;
}
/* %endif */

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
			return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr )
{
			free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

/* %if-tables-serialization definitions */
/* %define-yytables   The name for this specific scanner's tables. */
#define YYTABLES_NAME "yytables"
/* %endif */

/* %ok-for-header */

#line 167 "servscan.l"

int yywrap( void )
{
   return 1;
}

void yyerror( const char *message )
{
   src_parse_error( stderr, yylval.token.src, message );
   err_fatal( __func__, "parse error\n" );
   exit( 1 );
}

static void include_file( void ) {
   const char *file;
   int i;
   for ( i = 8; yytext[i] == ' ' || yytext[i] == '\t'; ++i )
      ;  /* advance past include{WS} to filename */
   if ( yytext[i] == '"' )  /* process {string} */
      file = str_findn(yytext+i+1, yyleng-i-2);
   else                     /* process {word} */
      file = str_findn(yytext+i, yyleng-i);
   orig_source = src_get( yyleng );
   if ( orig_buffer ) {
      src_print_error( stderr, orig_source, NULL );
      err_fatal( __func__, "Nested includes are not permitted\n" );
      exit( 1 );
   }
   orig_buffer = YY_CURRENT_BUFFER;
   yyin = fopen( file, "r" );
   if ( ! yyin ) {
      src_print_error( stderr, orig_source, NULL );
      err_fatal( __func__, "Cannot open \"%s\" for read\n", file );
      exit( 1 );
   }
   src_new_file( file );
   src_new_line ( 0 );
   yy_switch_to_buffer(
      yy_create_buffer( yyin, YY_BUF_SIZE ) );
   BEGIN(INITIAL);
}

static void include_complete( void ) {
   const char *orig_line;
   yy_delete_buffer( YY_CURRENT_BUFFER );
   yy_switch_to_buffer( orig_buffer );
   orig_buffer = NULL;
   BEGIN(OTHER);
   src_new_file( src_filename( orig_source ) );
   orig_line = src_source_line( orig_source );
   src_line( orig_line, strlen( orig_line ) );
   src_new_line( src_linenumber( orig_source ) );
   src_advance( src_offset( orig_source ) + src_length( orig_source ) );
   orig_source = NULL;
}

